package simulator;



import java.util.List;

import dcworms.schedframe.scheduling.utils.JobDescription;
import dcworms.schedframe.scheduling.utils.TaskDescription;

import schedframe.scheduling.tasks.Job;
import schedframe.scheduling.tasks.JobInterface;


/**
 * This interface introduces a generic user entity, which is intended to send jobs and tasks
 * to a broker entity.
 * 
 * @author Stanislaw Szczepanowski
 * @param <SubJob> a job type, which implements the {@link Job} interface
 */
public interface GenericUser {

	/**
	 * @return a list of all jobs, that have been sent by the user entity
	 */
	public List<JobDescription> getAllSentJobs();
	
	/**
	 * @return a list of all tasks, that have been sent by the user entity
	 */
	public List<TaskDescription> getAllSentTasks();
	
	/**
	 * @return a list of all jobs, that have returned from execution to the user entity
	 */
	public List<JobInterface<?>> getAllReceivedJobs();
	
	/**
	 * @return the name of the user entity (unique in the entire simulation run)
	 */
	public String getUserName();
	
	public int getFinishedTasksCount() ;
	
	
	/**
	 * This method is intended for debug purposes.
	 * @return <code>true</code> if during the simulation, any error occurred 
	 * (e.g. the same job has been returned twice).
	 */
	public boolean isError();
}
